# Alvin CLI

The Alvin CLI package is developed for the users to access all the UI features in their terminal. The Alvin CLI is easy
to use with descriptive commands and information on requirements for all the commands. 


The `alvin_cli` package depends on the [`alvin_api_client`](https://pypi.org/project/alvin-api-client) package which is installed as a dependency during installation.


Find the Alvin CLI documentation [here](https://docs.alvin.ai/developer-resources/cli).


Other resources

- Alvin [docs](https://docs.alvin.ai)
- Request Invite [here](https://www.alvin.ai)


